from setuptools import setup

setup(
    name='causaldag',
    version='0.1a',
    description='Causal DAG manipulation and inference',
    url='http://github.com/storborg/funniest',
    author='Chandler Squires',
    author_email='chandlersquires18@gmail.com',
    packages=['causaldag'],
    zip_safe=False
)




from .classes.dag import DAG
import numpy as np


def load_gml(filename):
    pass


def from_amat(amat):
    arcs = set()
    for (i, j), val in np.ndenumerate(amat):
        if val != 0:
            arcs.add((i, j))
    return DAG(arcs=arcs)


